@@ -1,5 +1,9 @@
 #' @import magrittr forestmodel
+#' @importFrom dplyr if_else
 cox_panel <- function(headings = list(variable = "Group", n = "N", measure = "Hazard ratio", ci = NULL, p = "p")) {
+
+  is_na <- function(x) sapply(x, is.na)
+
   panels <- list(
     forest_panel(width = 0.03),
     forest_panel(width = 0.1, display = variable, fontface = "bold", heading = headings$variable),
@@ -13,7 +17,7 @@ cox_panel <- function(headings = list(variable = "Group", n = "N", measure = "Ha
     forest_panel(width = 0.03, item = "vline", hjust = 0.5),
     forest_panel(
       width = 0.12,
-      display = dplyr::if_else(reference, dplyr::if_else(!is.numeric(p.value), "Reference", "Reference;  Variable logrank:"),
+      display = if_else(reference, if_else(is_na(p.value), "Reference", "Reference;  Variable logrank:"),
         sprintf("%0.2f (%0.2f, %0.2f)", trans(estimate), trans(conf.low), trans(conf.high))
       ),
       heading = headings$ci,
@@ -21,7 +25,7 @@ cox_panel <- function(headings = list(variable = "Group", n = "N", measure = "Ha
     ),
     forest_panel(
       width = 0.05,
-      display = dplyr::if_else(reference & !is.numeric(p.value), "", format.pval(p.value, digits = 1, eps = 1e-3)), display_na = NA,
+      display = if_else(reference & is_na(p.value), "", format.pval(p.value, digits = 1, eps = 1e-3)), display_na = NA,
       hjust = 1, heading = headings$p
     ),
     forest_panel(width = 0.03)
