@@ -5,8 +5,8 @@
 =======================================================================
 ", "You are using ", pkgname, " version ", version, "
 
-Github page  : https://github.com/ShixiangWang/ezcox
-Documentation: https://shixiangwang.github.io/ezcox/articles/ezcox.html
+Project home : https://github.com/ShixiangWang/ezcox
+Documentation: https://shixiangwang.github.io/ezcox
 
 Run citation(\"ezcox\") to see how to cite 'ezcox'.
 =======================================================================
